@@ -6,10 +6,22 @@ author: C. Lockhart <chris@lockhartlab.org>
 
 from simlib.core import Topology, Trajectory
 
+from fileinput import input as finput
+from glob import glob
 import numpy as np
 # from numpy.lib.recfunctions import drop_fields, structured_to_unstructured
 import pandas as pd
 import re
+from typelike import ArrayLike
+
+
+
+def loadtxt(filename, glob=False):
+    if not glob:
+        result = np.loadtxt(filename)
+    else:
+        result = np.loadtxt(finput(sorted(glob(filename))))
+    return result
 
 
 # Read PDB
@@ -46,6 +58,61 @@ def read_pdb(filename, backend='python'):
     return _read_pdb(records)
 
 
+def read_peptide_sequence(residues):
+    """
+    Create trajectory from an amino acid sequence.
+
+    Parameters
+    ----------
+    residues : str or ArrayLike
+        List of amino acids.
+
+    Returns
+    -------
+    simlib.Trajectory
+        Instance of Trajectory.
+    """
+
+    # Convert to list if not already list
+    if not isinstance(residues, ArrayLike):
+        residues = list(residues)
+
+    # Make sure we're in the right format
+    letter_to_code = {
+        'A': 'ALA',
+        'R': 'ARG',
+        'N': 'ASN',
+        'D': 'ASP',
+        'C': 'CYS',
+        'Q': 'GLN',
+        'E': 'GLU',
+        'G': 'GLY',
+        'H': 'HIS',
+        'I': 'ILE',
+        'L': 'LEU',
+        'K': 'LYS',
+        'M': 'MET',
+        'F': 'PHE',
+        'P': 'PRO',
+        'S': 'SER',
+        'T': 'THR',
+        'W': 'TRP',
+        'Y': 'TYR',
+        'V': 'VAL'
+    }
+    residues = [letter_to_code.get(residue, residue) for residue in residues]
+
+    # Create Trajectory
+    topology = Topology()
+    topology._data = pd.DataFrame({'residue_id': np.arange(len(residues)), 'residue': residues})
+
+    # Create Trajectory
+    trajectory = Trajectory(xyz=np.zeros((1, len(residues), 3)), topology=topology)
+
+    # Return
+    return trajectory
+
+
 def _read_pdb(records):
     # Filter out atom records
     # TODO this will be slow for large PDB files; perhaps move to Cython or C backend
